==> 0.0.79.tar.gz: lib/screens/payment_webview.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_firebase_basic_tools/logic/multiplatform_webview/multiplatform_webview_mobile.dart';

class PaymentWebview extends StatelessWidget {
  String get htmlContent => """
<!DOCTYPE html>
<html>
<head>
<script src="https://js.stripe.com/v3/"></script>
</head>
<body>
<script>

/* Handle any errors returns from Checkout  */
var handleResult = function(result) {
  if (result.error) {
    var displayError = document.getElementById('error-message');
    displayError.textContent = result.error.message;
  }
};

// Create a Checkout Session with the selected quantity
var createCheckoutSession = function() {
  return fetch('https://us-central1-abei-21f7c.cloudfunctions.net/createStripeCheckoutSession/create-checkout-session?priceID=[price_id]&userID=[user_id]&courseID=[course_id]&customerEmail=[customer_email]', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
  }).then(function(result) {
    return result.json();
  });
};

function myNewFunction() {
  console.log("hello my friend");
  var stripe = Stripe("[publishable_key]");
  
  createCheckoutSession().then(function(data) {
    stripe
      .redirectToCheckout({
        sessionId: data.sessionId,
      })
      .then(handleResult);
  });
}

myNewFunction();

</script>
</body>
</html>
""";

  StripePayment args;

  @override
  Widget build(BuildContext context) {
    args = ModalRoute.of(context).settings.arguments;

    String acmePublishableKey = "pk_test_DcdV100E4ZWqymIJWFRZ31Az00Fn3Q2Lo7";

    //String abeiPublishableKey = "pk_test_MTUyGEzPBapFimrhnTEBAwPY"; // TEST
    String abeiPublishableKey = "pk_live_yGe5QnCHNrughBRNhQXkPlcz"; //  PROD

    String customHtmlContent1 =
        htmlContent.replaceAll('[price_id]', args.priceID);

    String customHtmlContent2 =
        customHtmlContent1.replaceAll('[user_id]', args.userID);

    String customHtmlContent3 =
        customHtmlContent2.replaceAll('[customer_email]', args.customerEmail);

    String customHtmlContent4 =
        customHtmlContent3.replaceAll('[publishable_key]', abeiPublishableKey);

    String customHtmlContent5 =
        customHtmlContent4.replaceAll('[course_id]', args.courseID);

    return Scaffold(
      body: SafeArea(
        child: MultiplatformWebview(
          src:
              "https://us-central1-abei-21f7c.cloudfunctions.net/stripeSessionView?priceID=${args.priceID}&userID=${args.userID}&courseID=${args.courseID}&customerEmail=${args.customerEmail}",
        ),
      ),
    );
  }
}

class StripePayment {
  final String priceID;
  final String userID;
  final String customerEmail;
  final String courseID;

  StripePayment({
    this.priceID,
    this.userID,
    this.customerEmail,
    this.courseID,
  });
}

==> 0.0.146.tar.gz: lib/screens/payment_webview.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_firebase_basic_tools/logic/multiplatform_webview/multiplatform_webview.dart';
import 'package:uuid/uuid.dart';

class PaymentWebview extends StatelessWidget {
  const PaymentWebview({
    @required this.stripePayment,
  });

  final StripePayment stripePayment;

  String get htmlContent => """
<!DOCTYPE html>
<html>
<head>
<script src="https://js.stripe.com/v3/"></script>
</head>
<body>
<script>

/* Handle any errors returns from Checkout  */
var handleResult = function(result) {
  if (result.error) {
    var displayError = document.getElementById('error-message');
    displayError.textContent = result.error.message;
  }
};

// Create a Checkout Session with the selected quantity
var createCheckoutSession = function() {
  return fetch('https://us-central1-abei-21f7c.cloudfunctions.net/createStripeCheckoutSession/create-checkout-session?priceID=[price_id]&userID=[user_id]&courseID=[course_id]&customerEmail=[customer_email]', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
  }).then(function(result) {
    return result.json();
  });
};

function myNewFunction() {
  console.log("hello my friend");
  var stripe = Stripe("[publishable_key]");
  
  createCheckoutSession().then(function(data) {
    stripe
      .redirectToCheckout({
        sessionId: data.sessionId,
      })
      .then(handleResult);
  });
}

myNewFunction();

</script>
</body>
</html>
""";

  @override
  Widget build(BuildContext context) {
    String acmePublishableKey = "pk_test_DcdV100E4ZWqymIJWFRZ31Az00Fn3Q2Lo7";

    //String abeiPublishableKey = "pk_test_MTUyGEzPBapFimrhnTEBAwPY"; // TEST
    String abeiPublishableKey = "pk_live_yGe5QnCHNrughBRNhQXkPlcz"; //  PROD

    String customHtmlContent1 =
        htmlContent.replaceAll('[price_id]', stripePayment.priceID);

    String customHtmlContent2 =
        customHtmlContent1.replaceAll('[user_id]', stripePayment.userID);

    String customHtmlContent3 = customHtmlContent2.replaceAll(
        '[customer_email]', stripePayment.customerEmail);

    String customHtmlContent4 =
        customHtmlContent3.replaceAll('[publishable_key]', abeiPublishableKey);

    String customHtmlContent5 =
        customHtmlContent4.replaceAll('[course_id]', stripePayment.courseID);

    return Scaffold(
      body: SafeArea(
        child: MultiplatformWebview(
          src:
              "https://us-central1-abei-21f7c.cloudfunctions.net/stripeSessionView?priceID=${stripePayment.priceID}&userID=${stripePayment.userID}&courseID=${stripePayment.courseID}&customerEmail=${stripePayment.customerEmail}",
          id: Uuid().v4(),
        ),
      ),
    );
  }
}

class StripePayment {
  final String priceID;
  final String userID;
  final String customerEmail;
  final String courseID;

  StripePayment({
    this.priceID,
    this.userID,
    this.customerEmail,
    this.courseID,
  });
}
